library("ggplot2")
library("gdata")
library("dplyr")

# Read networks:
ISingNCS <- read.xls("ForbesTable2_replication.xls",2,header=FALSE)
ISingNSMHWB <- read.xls("ForbesTable2_replication.xls",3,header=FALSE)
RelImpNCS <- read.xls("ForbesTable2_replication.xls",6,header=FALSE)
RelImpNSMHWB <- read.xls("ForbesTable2_replication.xls",7,header=FALSE)
DAGNCS <- read.xls("ForbesTable2_replication.xls",8,header=FALSE)
DAGNSMHWB <- read.xls("ForbesTable2_replication.xls",9,header=FALSE)


toDF <- function(x,model,data){
  data.frame(
    weight = unlist(x),
    from = c(row(x)),
    to = c(col(x)),
    model = model,
    data = data
  )
}

# Data frames:
DF <- rbind(
  dfIsingNCS = toDF(ISingNCS,"Ising","NCS-R"),
  dfIsingNSMHWB = toDF(ISingNSMHWB,"Ising","NSMHWB"),
  RelImpNCS = toDF(RelImpNCS,"Relative importance","NCS-R"),
  RelImpNSMHWB = toDF(RelImpNSMHWB,"Relative importance","NSMHWB"),
  DAGNCS = toDF(DAGNCS,"DAG","NCS-R"),
  DAGNSMHWB = toDF(DAGNSMHWB,"DAG","NSMHWB")
)

DF <- DF%>% group_by(model) %>% mutate(weightScale= weight/max(weight))

p <- ggplot(DF, aes(x=from,y=to,fill=weightScale)) + geom_tile(colour = "white") + 
  scale_fill_gradient2("weight/max(weight)",low = "red", high = "steelblue", mid = "white", 
                      midpoint = 0, limit = c(-1,1), space = "Lab") + 
  facet_grid(data ~ model, scale = "free") + 
  geom_text(aes(label=round(weight,2)),size = 1.5)
p
base_size <- 9
p <- p + theme_grey(base_size = base_size) + labs(x = "",y = "") + 
  scale_x_discrete(expand = c(0, 0)) +
  scale_y_discrete(expand = c(0, 0)) + 
  theme(legend.position = "none",axis.ticks = element_blank(), axis.text.x = element_text(size = base_size *0.8, angle = 330, hjust = 0, colour = "grey50"),
        panel.border = element_rect(color = "black", fill = NA, size = 1),
        panel.margin=unit(0, "lines"))

pdf("heatmap.pdf",width=12,height=8)

print(p)

dev.off()
